@@ -22,7 +22,7 @@
       project version	: Please see "main.cpp" for project version
 
       developer 		: luckyb 
-      last modified 		: 15 Jun 2010
+      last modified 		: 23 Aug 2010
       ===============================================================================================================================
       ===============================================================================================================================
 */
@@ -53,7 +53,7 @@ void aboutDialog::okay()
 // FUNCTIONS-------------------------------------------------------------------------------------
 void aboutDialog::setTop()
 {
-	Text = appName+" "+ countStr.setNum(appVersion);
+	Text = appName+" "+ appVersionString;
 	uiA.label_Top -> setText(Text);
 }
 void aboutDialog::setAbout()
@@ -61,7 +61,7 @@ void aboutDialog::setAbout()
 	uiA.textBrowser_About -> setOpenLinks(TRUE);
 	uiA.textBrowser_About -> setOpenExternalLinks(TRUE);
 
-	Text = 	"<p align=\"center\"><b>"+appName + " " + countStr.setNum(appVersion) +"</b> ("+
+	Text = 	"<p align=\"center\"><b>"+appName + " " + appVersionString +"</b> ("+
 		tr("using Qt4")+")" + "<br>" +
 		tr("Backup & Sync Application")+"<br><br>"
 
@@ -182,6 +182,12 @@ void aboutDialog::setThanks()
 		"<b>" + tr("E. Hakan Duran") + "</b><br>" +
 		tr("Turkish gui translator") + "<br><br>"
 		
+		"<b>" + tr("Marvin Gomez") + "</b><br>" +
+		tr("Spanish gui translator") + "<br><br>"
+
+		"<b>" + tr("Fredrik Holmgren") + "</b><br>" +
+		tr("Swedish gui translator") + "<br><br>"
+		
 		"<b>" + tr("Javi Romero") + "</b><br>" +
 		tr("v0.3 gui designer") + "<br><br>"
 
@@ -191,6 +197,9 @@ void aboutDialog::setThanks()
 		"<b>" + tr("Tito Poquito") + "</b><br>" +
 		tr("slackware package maintainer (SlackBuilds Repository)") + "<br><br>" +
 		
+		 "<b>" + tr("Michele Dall'Arno") + "</b><br>" +
+		tr("special guest bug killer ;)") + "<br><br>" +
+		
 		tr("...to all users of the ")+
 		"<br><a href=\"http://www.linuxformat.gr/\" target=\"_blank\">Hellenic Linuxformat</a>, "
 		"<a href=\"http://www.sidux.com/\" target=\"_blank\">sidux.com</a>, "
@@ -199,7 +208,7 @@ void aboutDialog::setThanks()
 		"<a href=\"http://forum.hellug.gr/\" target=\"_blank\">hellug</a>, "
 		"and <a href=\"http://www.kde-apps.org//\" target=\"_blank\">kde-apps.org</a><br>" +
 		tr("forums for their support.") + "<br><br>" +
-		tr("Especially") + "<br>alfisti, constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Ray Ambrosi, Barry Jackson, Damien Cassou, Carsten, Daniele Soldati Chris (slam), Paul Chapman, kingfame, Giorgos 'jeff' Finikianakis, Shelby Williams, Felix, skevo, Philipp F, Christian Harms, Paul Hewlett and Tristan Gross<br>" +
+		tr("Especially") + "<br>alfisti, constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Ray Ambrosi, Barry Jackson, Damien Cassou, Carsten, Daniele Soldati Chris (slam), Paul Chapman, kingfame, Giorgos 'jeff' Finikianakis, Shelby Williams, Felix, skevo, Philipp F, Christian Harms, Paul Hewlett, Tristan Gross, Fabian Muscariello, James Mohr and Julie Pierson<br>" +
 		tr("that contributed to this project one way or another") + "<br><br>" +
 
 		tr("Last but no least") +":<br>"+
