@@ -19,7 +19,7 @@
      You should have received a copy of the GNU General Public License
      along with luckyBackup.  If not,see <http://www.gnu.org/licenses/>.
  developer 		: luckyb 
- last modified 		: 14 Jun 2010
+ last modified 		: 17 Oct 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -109,6 +109,7 @@ void commandline::rsyncIT()
 
 		if ( (Operation[currentOperation] -> GetPerform()) || (Operation[currentOperation] -> GetByPassWARNING()) )
 		{
+			bool RemoteDestUsed = (Operation[currentOperation] -> GetRemoteDestination()) && (Operation[currentOperation] -> GetRemote());
 			//update the last execution time + logfile actions ~~~~~~~~~~~~~~~~~~~~~
 			if (!DryRun)
 			{
@@ -120,14 +121,80 @@ void commandline::rsyncIT()
 					currentSnaps = 1;
 
 				// first remove the older logfiles and snapshots if max keep snapshots is reached
-// *********************************************************** WARNING THIS ONLY WORKS LOCALLY ***********************************************************************
-				bool RemoteDestUsed = (Operation[currentOperation] -> GetRemoteDestination()) && (Operation[currentOperation] -> GetRemote());
-				if ( (currentSnaps >= maxSnaps) &&  (!RemoteDestUsed) )
+				if (currentSnaps >= maxSnaps)
 				{
 					cout << "\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n";
 					cout << " Removing old snapshots and logfiles of task: " <<
 						QString((Operation[currentOperation] -> GetName()).toUtf8()).toStdString() << "\n";
 				
+					// ************** actually REMOVE DATA of all older snapshots ***************************
+					// ******************************************************************************
+					// First calculate the folder where snapshots go
+					QStringList tempArguments = Operation[currentOperation] -> GetArgs();
+					QString tempSource = tempArguments[tempArguments.size()-2];
+					QString tempDestination = tempArguments[tempArguments.size()-1];
+					QString sourceLast = tempSource;
+					if (!tempSource.endsWith("/"))	// this means task is of type "backup dir by name"
+					{
+						if (sourceLast.contains(":"))	// this is normal for a remote directory
+							sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
+						if (tempSource.contains("/"))	// this is normal for a directory unless it is remote
+							sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
+						
+						tempSource.append("/");
+						tempDestination.append(sourceLast + "/");
+					}
+					tempDestination.append (snapDefaultDir);
+					
+					// increase the remove limit to include the source.size() if "backup dir by name" is used
+					if (Operation[currentOperation] -> GetTypeDirName())
+						removeCharLimit = 4 + sourceLast.size()+1;
+					else
+						removeCharLimit = 4;
+					
+					QProcess *rmProcess;	rmProcess  = new QProcess;
+					QStringList rmArgs;
+					rmArgs << "--progress" << "-r" << "--delete-after";
+					int snapToKeep = currentSnaps-maxSnaps + 1;
+					while ( snapToKeep < currentSnaps )
+					{
+						rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + "/");
+						snapToKeep++;
+					}
+					
+					//also add all remote arguments exactly as used at normal backup
+					if (RemoteDestUsed)
+					{
+						if ( Operation[currentOperation] -> GetRemotePassword() != "")
+							rmArgs.append("--password-file=" + ( Operation[currentOperation] -> GetRemotePassword()) );
+						if ( Operation[currentOperation] -> GetRemoteSSH())
+						{
+							if ( Operation[currentOperation] -> GetRemoteSSHPassword() != "")
+								if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+									rmArgs.append("-e ssh -i " +  Operation[currentOperation] -> GetRemoteSSHPassword() +" -p " +
+												countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+								else
+									rmArgs.append("-e ssh -i " +  Operation[currentOperation] -> GetRemoteSSHPassword());
+							else
+								if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+									rmArgs.append("-e ssh -p " + countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+								else
+									rmArgs.append("-e ssh");
+						}
+					}
+					
+					rmArgs.append(snapEmptyDir);
+					rmArgs.append(tempDestination);
+			
+					rmProcess -> start ("rsync",rmArgs);
+					rmProcess -> waitForFinished();
+					
+					if ((rmProcess -> exitCode()) == 0)
+						cout << "\nRemoved  all older snapshots data";// << QString((tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/").toUtf8()).toStdString();
+					else
+						cout << "\nfailed to remove all older snapshots data";// << QString((tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/").toUtf8()).toStdString() << "\n";
+				// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+				
 					count = 0;
 					while ( count < (currentSnaps -maxSnaps + 1 ) )
 					{
@@ -157,47 +224,6 @@ void commandline::rsyncIT()
 								cout << "\nfailed to remove " << QString(logfilename.toUtf8()).toStdString() << "\n";
 						}
 						
-						// ************** actually REMOVE DATA of snapshot(0) ***************************
-						// ******************************************************************************
-						// First calculate the folder where snapshots go
-						QStringList tempArguments = Operation[currentOperation] -> GetArgs();
-						QString tempSource = tempArguments[tempArguments.size()-2];
-						QString tempDestination = tempArguments[tempArguments.size()-1];
-						QString sourceLast = tempSource;
-						if (!tempSource.endsWith("/"))	// this means task is of type "backup dir by name"
-						{
-							if (sourceLast.contains(":"))	// this is normal for a remote directory
-								sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
-							if (tempSource.contains("/"))	// this is normal for a directory unless it is remote
-								sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
-							
-							tempSource.append("/");
-							tempDestination.append(sourceLast + "/");
-						}
-						tempDestination.append (snapDefaultDir + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/");
-						
-						// increase the remove limit to include the source.size() if "backup dir by name" is used
-						if (Operation[currentOperation] -> GetTypeDirName())
-							removeCharLimit = 4 + sourceLast.size()+1;
-						else
-							removeCharLimit = 4;
-						
-						QDir snapToRemoveDir(tempDestination);
-						if (snapToRemoveDir.exists())
-						{
-							QProcess *rmProcess;	rmProcess  = new QProcess;
-							QStringList rmArgs;
-							rmArgs << "-rvf" << tempDestination;
-							rmProcess -> start ("rm",rmArgs);
-							rmProcess -> waitForFinished();
-							
-							if ((rmProcess -> exitCode()) == 0)
-								cout << "\nRemoving " << QString(tempDestination.toUtf8()).toStdString();
-							else
-								cout << "\nfailed to remove " << QString(tempDestination.toUtf8()).toStdString() << "\n";
-						}
-						// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
 						//remove the oldest snapshot (0) from the list
 						Operation[currentOperation] -> RemoveSnapshotsListItem (0);
 						count++;
@@ -308,7 +334,7 @@ void commandline::rsyncIT()
 				
 				dirB = rsyncArguments[rsyncArguments.size()-1];
 				QDir destCreate (dirB.toUtf8());
-				if ( (!destCreate.exists()) && (!Operation[currentOperation] -> GetTypeSync()) )
+				if ( (!destCreate.exists()) && (!Operation[currentOperation] -> GetTypeSync()) && (!RemoteDestUsed) ) // local use ONLY
 				{
 					if (destCreate.mkpath(dirB.toUtf8()))
 					{
