@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 04 Jun 2010
+ last modified 		: 18 Oct 2010
 ===============================================================================================================================
 ===============================================================================================================================
  ********************************** DO NOT FORGET TO CHANGE "commandline.cpp:rsyncIT()" ********************************************************
@@ -40,6 +40,9 @@ void luckyBackupWindow::executeNOW ()
 	ABORTpressed = FALSE;		//becomes true if abort button pressed
 	//change gui to execute mode !!
 	guiModeNormal = FALSE;
+	
+	(ui.rsyncOutput->document())->setMaximumBlockCount(50000);	// set the maximum block count for the output window to avoid freezing
+	
 	swapGUI("execution");
 	ui.AbortButton -> setVisible (TRUE);
 	ui.DoneButton -> setVisible (FALSE);
@@ -135,7 +138,10 @@ void luckyBackupWindow::swapGUI(QString GUImode)
 		//ui.pushButton_InfoCollapse -> setChecked(!IsVisibleInfoWindow);
 		ui.nowDoing	-> setVisible (IsVisibleInfoWindow);
 		ui.OperationProgress -> setVisible (TRUE);
-		ui.pushButton_minimizeToTray	-> setVisible (TRUE);
+		if (QSystemTrayIcon::isSystemTrayAvailable ())
+			ui.pushButton_minimizeToTray	-> setVisible (TRUE);
+		else
+			ui.pushButton_minimizeToTray	-> setVisible (FALSE);
 		ui.pushButton_nextError	-> setVisible (TRUE);
 		ui.pushButton_previousError	-> setVisible (TRUE);
 		ui.pushButton_nextError	-> setEnabled (FALSE);
@@ -184,7 +190,9 @@ void luckyBackupWindow::donePressed()
 	ui.rsyncOutput -> setText("");
 	guiModeNormal = TRUE;
 	swapGUI("normal");
-	LBtray -> hide();	// hide the tray icon
+
+	if (QSystemTrayIcon::isSystemTrayAvailable ())	// this prevents a segfault when system tray is NOT available
+		LBtray -> hide();	// hide the tray icon
 	
 	refreshList(); //refresh the listWidget_operations
 	
@@ -226,6 +234,7 @@ void luckyBackupWindow::abortPressed()
 
 // createTrayIcon =============================================================================================================================
 // create the tray icon
+// This is only called when system tray is available
 void luckyBackupWindow::createTrayIcon()
 {
 	//actions----------------------------------
@@ -267,18 +276,24 @@ void luckyBackupWindow::createTrayIcon()
 // minimizes the gui to the tray
 void luckyBackupWindow::minimizeTray()
 {
+	if (QSystemTrayIcon::isSystemTrayAvailable ())
+	{
+		minimizeToTray 	-> setVisible(FALSE);
+		restoreFromTray	-> setVisible(TRUE);
+	}
 	isMinimizedToTray = TRUE;
-	minimizeToTray 	-> setVisible(FALSE);
-	restoreFromTray	-> setVisible(TRUE);
 	this -> hide();
 }
 // restoreTray =============================================================================================================================
 // restores the gui from the tray
 void luckyBackupWindow::restoreTray()
 {
+	if (QSystemTrayIcon::isSystemTrayAvailable ())
+	{
+		minimizeToTray 	-> setVisible(TRUE);
+		restoreFromTray	-> setVisible(FALSE);
+	}
 	isMinimizedToTray = FALSE;
-	minimizeToTray 	-> setVisible(TRUE);
-	restoreFromTray	-> setVisible(FALSE);
 	this -> showNormal();
 }
 // LBtrayActivated============================================================================================================
@@ -327,20 +342,90 @@ void luckyBackupWindow::executeBeforeTask()
 			currentSnaps = 1;
 		
 		// first remove the older logfiles and snapshots if max keep snapshots is reached
-// *********************************************************** WARNING THIS ONLY WORKS LOCALLY ***********************************************************************
+		
 		bool RemoteDestUsed = (Operation[currentOperation] -> GetRemoteDestination()) && (Operation[currentOperation] -> GetRemote());
-		if ( (currentSnaps >= maxSnaps) &&  (!RemoteDestUsed) )
+		if (currentSnaps >= maxSnaps)
 		{
 			outputInsert = "\n<font color=magenta>" +
 				tr("Removing old snapshots and logfiles of task","info message displayed during ...data removal\nFull phrase: Removing old snapshots and logfiles of task: <TASKNAME>") +
 				": <b>" + Operation[currentOperation] -> GetName() +
 				"</b></font><br>=====================================<br>";
 			ui.rsyncOutput->append(outputInsert);
+			
+			// **************Remove actual backup data ***************************************************
+				
+			// First calculate the folder where snapshots go
+			QStringList tempArguments = Operation[currentOperation] -> GetArgs();
+			QString tempSource = tempArguments[tempArguments.size()-2];
+			QString tempDestination = tempArguments[tempArguments.size()-1];
+			QString sourceLast = tempSource;
+			if (!tempSource.endsWith("/"))	// this means task is of type "backup dir by name"
+			{
+				if (sourceLast.contains(":"))	// this is normal for a remote directory
+					sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
+				if (tempSource.contains("/"))	// this is normal for a directory unless it is remote
+					sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
+				
+				tempSource.append("/");
+				tempDestination.append(sourceLast + "/");
+			}
+			tempDestination.append (snapDefaultDir);
+			
+			// increase the remove limit to include the source.size() if "backup dir by name" is used
+			if (Operation[currentOperation] -> GetTypeDirName())
+				removeCharLimit = 4 + sourceLast.size()+1;
+			else
+				removeCharLimit = 4;
+			
+			//we will delete the snapshots directory by using an rsync command with an empty source:
+			QProcess *rmProcess;
+			rmProcess  = new QProcess(this);
+			QStringList rmArgs;
+			rmArgs << "--progress" << "-r" << "--delete-after";
+			int snapToKeep = currentSnaps-maxSnaps + 1;
+			while ( snapToKeep < currentSnaps )
+			{
+				rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + "/");
+				snapToKeep++;
+			}
+			
+			//also add all remote arguments exactly as used at normal backup
+			if (RemoteDestUsed)
+			{
+				if ( Operation[currentOperation] -> GetRemotePassword() != "")
+					rmArgs.append("--password-file=" + ( Operation[currentOperation] -> GetRemotePassword()) );
+				if ( Operation[currentOperation] -> GetRemoteSSH())
+				{
+					if ( Operation[currentOperation] -> GetRemoteSSHPassword() != "")
+						if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+							rmArgs.append("-e ssh -i " +  Operation[currentOperation] -> GetRemoteSSHPassword() +" -p " +
+										countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+						else
+							rmArgs.append("-e ssh -i " +  Operation[currentOperation] -> GetRemoteSSHPassword());
+					else
+						if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+							rmArgs.append("-e ssh -p " + countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+						else
+							rmArgs.append("-e ssh");
+				}
+			}
+			
+			rmArgs.append(snapEmptyDir);
+			rmArgs.append(tempDestination);
+			rmProcess -> start ("rsync",rmArgs);
+			rmProcess -> waitForFinished();
+			
+			if ((rmProcess -> exitCode()) == 0)
+				ui.rsyncOutput->append("\n" + tr("Removed all older snapshots data"));// +" " + tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/");
+			else
+				ui.rsyncOutput->append("\n" + tr("failed to remove all older snapshots data"));// +" " + tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/");
+			
+			//******************************************************
 		
 			count = 0;
 			while ( count < (currentSnaps -maxSnaps + 1 ) )
 			{
-				//remove the changes file
+				//remove the changes file ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 				snapchangesfilename = snapChangesDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
 							(Operation[currentOperation] -> GetSnapshotsListItem(0)) + ".changes.log";
 				snapfile.setFileName(snapchangesfilename);
@@ -352,7 +437,7 @@ void luckyBackupWindow::executeBeforeTask()
 						ui.rsyncOutput->append("\n" + tr("failed to remove") +" " + snapchangesfilename);
 				}
 				
-				//remove the oldest logfile
+				//remove the oldest logfile ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 				logfilename = logDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
 							(Operation[currentOperation] -> GetSnapshotsListItem(0)) + ".log";
 				logfile.setFileName(logfilename); // this is the old logfile
@@ -363,61 +448,12 @@ void luckyBackupWindow::executeBeforeTask()
 					else
 						ui.rsyncOutput->append("\n" + tr("failed to remove") +" " + logfilename);
 				}
-				
-				// **************Remove actual backup data ********
-				
-				// First calculate the folder where snapshots go
-				QStringList tempArguments = Operation[currentOperation] -> GetArgs();
-				QString tempSource = tempArguments[tempArguments.size()-2];
-				QString tempDestination = tempArguments[tempArguments.size()-1];
-				QString sourceLast = tempSource;
-				if (!tempSource.endsWith("/"))	// this means task is of type "backup dir by name"
-				{
-					if (sourceLast.contains(":"))	// this is normal for a remote directory
-						sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
-					if (tempSource.contains("/"))	// this is normal for a directory unless it is remote
-						sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
-					
-					tempSource.append("/");
-					tempDestination.append(sourceLast + "/");
-				}
-				tempDestination.append (snapDefaultDir + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/");
-				
-				// increase the remove limit to include the source.size() if "backup dir by name" is used
-				if (Operation[currentOperation] -> GetTypeDirName())
-					removeCharLimit = 4 + sourceLast.size()+1;
-				else
-					removeCharLimit = 4;
-				
-				QDir snapToRemoveDir(tempDestination);
-				if (snapToRemoveDir.exists())
-				{
-					QProcess *rmProcess;
-					rmProcess  = new QProcess(this);
-					QStringList rmArgs;
-					rmArgs << "-rvf" << tempDestination;
-					rmProcess -> start ("rm",rmArgs);
-					rmProcess -> waitForFinished();
-					
-					
-					if ((rmProcess -> exitCode()) == 0)
-						ui.rsyncOutput->append("\n" + tr("Removing") +" " + tempDestination);
-					else
-						ui.rsyncOutput->append("\n" + tr("failed to remove") +" " + tempDestination);
-				}
 
 				//remove the oldest snapshot (0) from the list
 				Operation[currentOperation] -> RemoveSnapshotsListItem (0);
 				count++;
 			}
 		}
-		if (RemoteDestUsed)
-		{
-			outputInsert = "\n<font color=magenta>" +
-				tr("Using remote destination. Keeping all old snapshots intact","info message displayed during run") +
-				"</font><br>=====================================<br>";
-			ui.rsyncOutput->append(outputInsert);
-		}
 
 		//set the current date and time as the operation's last execution date-time
 		Operation[currentOperation] -> SetLastExecutionTime (QDateTime::currentDateTime());
@@ -549,6 +585,8 @@ void luckyBackupWindow::executeRsync()
 	
 	sync = Operation[currentOperation] -> GetTypeSync();		//set sync variable according to checkstate of radiobutton operation type
 	rsyncArguments = AppendArguments(Operation[currentOperation]);	//set rsync arguments
+	
+	bool RemoteDestUsed = (Operation[currentOperation] -> GetRemoteDestination()) && (Operation[currentOperation] -> GetRemote()); // Is remote dest used ?
 
 	if (DryRun)
 		rsyncArguments.insert(rsyncArguments.size()-2,"--dry-run");
@@ -585,7 +623,7 @@ void luckyBackupWindow::executeRsync()
 		
 		// Create the destination if it does not exist
 		QDir destCreate (dirB);
-		if (!destCreate.exists())
+		if ( (!destCreate.exists()) && (!RemoteDestUsed) ) // local use ONLY
 		{
 			if (destCreate.mkpath(dirB))
 				outputInsert.append(logFileUpdate("rsync-standard", "<br>" + tr("Successfuly created destination directory"), 0));
@@ -926,6 +964,9 @@ void luckyBackupWindow::finishUp()
 			
 		logfile.close();			// close the logfile
 	}
+
+	// TESTING-TESTING-TESTING-TESTING-TESTING-TESTING
+	//QMessageBox::information(this, "LB","QtextDocument title= **" + ui.rsyncOutput->documentTitle() +"**");
 }
 // previous error button pressed=====================================================================================================
 void luckyBackupWindow::previousErrorJump()
