@@ -22,7 +22,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
-//  last modified 	: 10 Jun 2010
+//  last modified 	: 18 Aug 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -75,8 +75,8 @@ void luckyBackupWindow::InitializeVariables()
 	if (manual.exists())	//if the manual is located in /usr/share/doc/luckybackup (normal installation)
 		helpURL.setUrl(systemManual);
 	manual.setFileName(relativeManual);
-	if (manual.exists())	//if the manual is located in /usr/share/doc/luckyb (normal installation)
-		helpURL.setUrl(relativeManual);
+	if (manual.exists())	//if the manual is located in relative path manual/ (app run from commandline)
+		helpURL.setUrl(QApplication::applicationDirPath() + "/" + relativeManual);
 
 	// licence actual path (QUrllicenseURL) --------------------------------------------------------
 	licenseURL.setScheme("file");
@@ -105,6 +105,8 @@ void luckyBackupWindow::retranslateUi()
 	ui.actionRefresh	-> setText(tr("&Refresh","This is a top 'Profile' menu action"));
 	ui.actionDefault	-> setText(tr("De&fault","This is a top 'Profile' menu action"));
 	ui.actionDefault	-> setToolTip(tr("Set as Default","This is a top 'Profile' menu action tooltip"));
+	ui.actionDescription	-> setText(tr("&View/Edit Description","This is a top 'Profile' menu action"));
+	ui.actionDescription	-> setToolTip(tr("View/Edit the profile description","This is a top 'Profile' menu action tooltip"));
 	ui.actionRename		-> setText(tr("R&ename","This is a top 'Profile' menu action"));
 	ui.actionDelete		-> setText(tr("&Delete","This is a top 'Profile' menu action"));
 	ui.actionNew 		-> setText(tr("&New","This is a top 'Profile' menu action"));
@@ -439,8 +441,8 @@ bool luckyBackupWindow::loadCurrentProfile()
 	if (loadOK == 2)			// if it is not a valid profile
 	{
 		loadData.append("<font color=red><b>" + tr("loading failed","information window message") + "</font></b><br>" +
-		tr("profile","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y")
-		+ " <b>" + profileName + "</b> " + tr("is not valid for","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y") + " " + appName +", "+ tr("version:","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y") + countStr.setNum(appVersion));
+		tr("profile ","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y'. BEWARE of the whitespace in the end")
+		+ "<b>" + profileName + "</b> " + tr("is not valid for","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y") + " " + appName +", "+ tr("version:","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y") + countStr.setNum(appVersion));
 		return FALSE;	//do nothing more
 	}
 
@@ -480,6 +482,14 @@ bool luckyBackupWindow::loadCurrentProfile()
 			loadData.append(tr("NO") + "</b>");
 	}
 	
+	//append the profile description if it exists
+	if (profileDescription != "")
+	{
+		QString profileDescriptionDisplay = profileDescription;
+		profileDescriptionDisplay.replace("\n","<br>");
+		loadData.append("<br><br><b>" + tr("Description") + ":</b><br>" + profileDescriptionDisplay);
+	}
+	
 	return TRUE;	//profile loaded successfuly
 }
 
@@ -500,9 +510,11 @@ bool luckyBackupWindow::saveCurrentProfile()
 	{
 		saveData.append("<font color=red><b>" + tr("WARNING") + "</b></font><br>");
 		if (currentProfile == defaultProfile)
-			saveData.append(tr("default","Information window message. Full phrase: 'default profile <PROFILENAME> could not be saved'") + " ");
-		saveData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> could not be saved'")+"<b>" + profileName + "</b> "+ tr("could not be saved","Information window message. Full phrase: 'profile <PROFILENAME> could not be saved'") + "<br>" +
-			"<font color=red>"+ profile.errorString() + "</font>");
+			saveData.append(tr("default profile","Information window message. Full phrase: 'default profile <PROFILENAME> could not be saved'."));
+		else
+			saveData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> could not be saved'"));
+			
+		saveData.append(" <b>" + profileName + "</b> "+ tr("could not be saved","Information window message. Full phrase: '(default) profile <PROFILENAME> could not be saved'") + "<br>" +	"<font color=red>"+ profile.errorString() + "</font>");
 			savedProfile = FALSE;
 		return FALSE;
 	}
@@ -524,6 +536,14 @@ bool luckyBackupWindow::saveCurrentProfile()
 			saveData.append(tr("NO") + "</b>");
 	}
 	
+	//append the profile description if it exists
+	if (profileDescription != "")
+	{
+		QString profileDescriptionDisplay = profileDescription;
+		profileDescriptionDisplay.replace("\n","<br>");
+		loadData.append("<br><br><b>" + tr("Description") + ":</b><br>" + profileDescriptionDisplay );
+	}
+	
 	savedProfile = TRUE;			//change profile status to "saved"
 	return TRUE;
 }
@@ -547,14 +567,14 @@ int luckyBackupWindow::createCurrentProfile()
 		{
 			createData.append("<font color=red><b>" + tr("WARNING") + "</b></font><br>");
 			if (currentProfile == defaultProfile)
-				createData.append(tr("default","Information window message. Full phrase: 'default profile <PROFILENAME> could not be created'") + " ");
-			createData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> could not be created'")+" <b>" + profileName + "</b> "+ tr("could not be created","Information window message. Full phrase: 'profile <PROFILENAME> could not be created'") + "<br>" +
-				"<font color=red>"+ profile.errorString() + "</font>");
+				createData.append(tr("default profile","Information window message. Full phrase: 'default profile <PROFILENAME> could not be created'."));
+			else
+				createData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> could not be created'."));
+			createData.append(" <b>" + profileName + "</b> "+ tr("could not be created","Information window message. Full phrase: '(default) profile <PROFILENAME> could not be created'") + "<br>" + "<font color=red>"+ profile.errorString() + "</font>");
 			return 2;	//profile could not be created
 		}
 
-		createData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> created successfully'") + " <b>" + profileName + "</b> <font color=green>"
-				+ tr("created successfully","Information window message. Full phrase: 'profile <PROFILENAME> created successfully'") + " !!</font>");
+		createData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> created successfully'") + " <b>" + profileName + "</b> <font color=green>" + tr("created successfully","Information window message. Full phrase: 'profile <PROFILENAME> created successfully'") + " !!</font>");
 		createProfileCombo();	// update the profile combobox with all existing profiles
 		savedProfile = TRUE;			//change profile status to "saved"
 		return 1;		// Profile created successfully
@@ -569,8 +589,8 @@ int luckyBackupWindow::isProfileSaved()
 	if (!savedProfile)	//if the current profile is not saved, ask the user if he/she wants to, before proceeding
 	{
 		textDialog textdialogQ ("QtQuestion",
-					tr("Profile","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")+" <b>" + profileName + "</b> " +
-					tr("is modified","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")+ ".<br><br>" +
+					tr("Profile","Question dialog message. Full phrase: 'profile <PROFILENAME> is modified'")+" <b>" + profileName + "</b> " +
+					tr("is modified","Question dialog message. Full phrase: 'profile <PROFILENAME> is modified'")+ ".<br><br>" +
 					tr("Would you like to save it before proceeding ?"), this);
 		textdialogQ.exec();
 		
@@ -579,7 +599,7 @@ int luckyBackupWindow::isProfileSaved()
 			if (!saveCurrentProfile())	// if it cannot be saved for any reason pop up a yes/no message box to go on or not
 			{
 				textDialog textdialogQ2 ("QtQuestion",
-					tr("Profile","Information window message. Full phrase: 'profile <PROFILENAME> could not be saved'")+" <b>" + profileName + "</b> " +tr("could not be saved","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")
+					tr("Profile","Question dialog message. Full phrase: 'profile <PROFILENAME> could not be saved'")+" <b>" + profileName + "</b> " +tr("could not be saved","Question dialog message. Full phrase: 'profile <PROFILENAME> could not be saved'")
 						+"<br><font color=red>"+ profile.errorString()
 						+ "</font><br><br>" + tr("Would you like to proceed anyway?"), this);
 				textdialogQ2.exec();
