@@ -23,13 +23,14 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 25 Nov 2009
+ last modified 		: 27 Aug 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
 
 
 #include "logDialog.h"
+#include "readLogFile.cpp"
 
 // class logDialog Constructor=================================================================================================
 
@@ -40,60 +41,63 @@ logDialog::logDialog (QUrl logUrl, QWidget *parent) : QDialog (parent)
 	errorCount = 0;
 	totalErrors = 0;
 	
+	readlogfile = new ReadLogFile(this);
+	connect( readlogfile, SIGNAL(error(const QString)), this, SLOT(refreshWindowError(const QString &)) );
+	connect( readlogfile, SIGNAL(newText(const QString)), this, SLOT(refreshWindow(const QString &)) );
+	connect( readlogfile, SIGNAL(terminated()), this, SLOT(logReadEnd()));
+	connect( readlogfile, SIGNAL(finished()), this, SLOT(logReadEnd()));
+	
+	(uiL.logView->document())->setMaximumBlockCount(50000);	// set maximum blocks to avoid freeze
+
 	connect ( uiL.button_close, SIGNAL( clicked() ), this, SLOT( closeLog() ) );	//connect close pushButton SLOT ----------------
 	connect ( uiL.button_previous, SIGNAL( clicked() ), this, SLOT( prevError() ) );	//connect previous pushButton SLOT
 	connect ( uiL.button_next, SIGNAL( clicked() ), this, SLOT( nextError() ) );	//connect next pushButton SLOT
-	
-	logUrl.setScheme("file");
-	if (logUrl.toString() == "file:Does_not_exist")			// if the logfile does not exist for a reason display a message
-	{
-		logText = tr("Could not locate the logfile") + "!!";
-		uiL.button_next -> setEnabled(FALSE);
-		uiL.button_previous -> setEnabled(FALSE);
-	}
-	else
-	{
-		if (!logfile.open(QIODevice::ReadOnly | QIODevice::Text))	//if it exists try to open it
-		{
-			logText = tr("Could not open the logfile") + "!!<br><font color=red>"+ logfile.errorString() + "</font>";
-			uiL.button_next -> setEnabled(FALSE);
-			uiL.button_previous -> setEnabled(FALSE);
-		}
-		else
-		{
-				
-			QTextStream in(&logfile);
-			int countLine = 0;
-			while (!in.atEnd())	// read the logfile line by line
-			{
-				QString logLine = in.readLine();
-				countLine++;
-				logLine.append("<br>");
-				logText.append(logLine);
-				
-				if (logLine.startsWith("<a name=\"error"))	// if the line is an error update the relevant errorLine Qstring
-				{
-					//errorLine[errorCount] = logLine;
-					errorLine.append("error" + countStr.setNum(errorCount+1));
-					errorCount++;
-				}
-				if (countLine > 50000)
-				{
-					logText.append("<br><br><font color=magenta><b>" + tr("Displaying first 50000 lines of logfile") + "</b></font>");
-					break;
-				}
-				
-			}
-			logfile.close();
-			totalErrors = errorCount;
-			if (totalErrors == 0)
-				uiL.button_next -> setEnabled(FALSE);
-			uiL.button_previous -> setEnabled(FALSE);
-			errorCount = 0;		//set current error to be the first of the logfile
-			firstScroll=TRUE;
-		}
-	}
-	uiL.logView -> setText(logText);
+
+	readlogfile -> setLogUrl(logUrl.toString());
+	QTimer::singleShot(500, this, SLOT(readLogFileNOW()));	// allow some time for the dialog to appear
+}
+
+// readLogFileNOW =====================================================================================================
+//Start a new thread to read the logfile
+void logDialog::readLogFileNOW()
+{
+	uiL.logView -> setText(tr("loading logfile..."));
+	uiL.button_close -> setText(tr("wait"));
+	readlogfile -> start();
+}
+
+// refreshWindow =====================================================================================================
+//Refresh the log window with text
+void logDialog::refreshWindow(const QString &newText)
+{
+	if (uiL.logView -> toPlainText() == "loading logfile...")
+		uiL.logView -> clear();
+	uiL.logView -> append(newText);
+	totalErrors = readlogfile -> TotalErrors();
+//	QCoreApplication::processEvents();
+}
+
+// logReadEnd =====================================================================================================
+//Do some stuff when finished reading log
+void logDialog::logReadEnd()
+{
+	if (totalErrors > 0)
+		uiL.button_next -> setEnabled(TRUE);
+	uiL.button_close -> setText(tr("close"));
+	uiL.button_close -> setEnabled(TRUE);
+	errorCount = 0;		//set current error to be the first of the logfile
+	firstScroll=TRUE;
+}
+
+// refreshWindowError =====================================================================================================
+//Refresh the log window with Error text
+void logDialog::refreshWindowError(const QString &errorText)
+{
+	uiL.logView -> setText(errorText);
+	uiL.button_next -> setEnabled(FALSE);
+	uiL.button_previous -> setEnabled(FALSE);
+	uiL.button_close -> setText(tr("close"));
+	uiL.button_close -> setEnabled(TRUE);
 }
 
 // close button pressed=====================================================================================================
@@ -113,7 +117,7 @@ void logDialog::prevError()
 	if (errorCount < totalErrors-1)	//if the current error is less than the last one within the logfile enable the next button
 		uiL.button_next -> setEnabled(TRUE);
 	
-	uiL.logView -> scrollToAnchor(errorLine[errorCount]);
+	uiL.logView -> scrollToAnchor("error" + countStr.setNum(errorCount+1));
 }
 
 // next button pressed=====================================================================================================
@@ -129,7 +133,7 @@ void logDialog::nextError()
 	if (errorCount > 0)				// if the current error is greater than the first one within the logfile enable the previous button
 		uiL.button_previous -> setEnabled(TRUE);
 	
-	uiL.logView -> scrollToAnchor(errorLine[errorCount]);	//scroll to the current error
+	uiL.logView -> scrollToAnchor("error" + countStr.setNum(errorCount+1));	//scroll to the current error
 }
 
 // end of logDialog.cpp ---------------------------------------------------------------------------
