@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 24 Apr 2010
+ last modified 		: 28 Aug 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -34,6 +34,8 @@
 //include  header file that qmake produces from "*.ui" created with qt designer
 #include "ui_logDialog.h"
 
+class ReadLogFile;
+
 //==============================================================================================================
 //Declaration of logDialog class (this will viw a log file in a dialog)
 class logDialog : public QDialog
@@ -43,19 +45,23 @@ class logDialog : public QDialog
 	public:
 		logDialog (QUrl, QWidget *parent=0);
 		QString logText;
-		QStringList errorLine;
+//		QStringList errorLine;
 		int errorCount;
 		int totalErrors;
 		bool firstScroll;
 
 	private slots:
-		void closeLog();		//SLOT when buutton close pressed
+		void closeLog();		//SLOT when button close pressed
 		void prevError();		//SLOT to scroll to next error
 		void nextError();		//SLOT to scroll to next error
+		void refreshWindow(const QString &);	//SLOT to refresh the log window
+		void refreshWindowError(const QString &);	//SLOT to refresh the log window
+		void readLogFileNOW();	// SLOT to read the logfile in a new thread
+		void logReadEnd();	//SLOT when finished reading logfile from disk
 
 	private:
 		Ui::logDialog uiL;
-
+		ReadLogFile *readlogfile;	// QThread that will read the logfile
 };
 
 #endif
