@@ -23,7 +23,7 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 project version	: Please see "main.cpp" for project version
 
 developer 	: luckyb 
-last modified 	: 12 Jun 2010
+last modified 	: 01 Sep 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -56,7 +56,7 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	InitializeVariables();
 
 	//create directory ~/.luckyBackup including folders "logs", "profiles", "schedule", snaps if they do not exist for the current user
-	QDir profiledir(profileDir), logdir(logDir), scheduledir(scheduleDir), snapdir(snapChangesDir);
+	QDir profiledir(profileDir), logdir(logDir), scheduledir(scheduleDir), snapdir(snapChangesDir), emptydir(snapEmptyDir);
 	if (!profiledir.exists())
 		profiledir.mkpath(profileDir);
 	if (!logdir.exists())
@@ -65,6 +65,21 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 		scheduledir.mkpath(scheduleDir);
 	if (!snapdir.exists())
 		snapdir.mkpath(snapChangesDir);
+	if (!emptydir.exists())
+		emptydir.mkpath(snapEmptyDir);
+	//check if the EMPTY dir is empty
+	QStringList emptyList = emptydir.entryList(QDir::AllEntries | QDir::Hidden | QDir::NoDotAndDotDot);
+	if (emptyList.size() > 0)
+	{
+		QProcess *rmProcess;
+		rmProcess  = new QProcess(this);
+		QStringList rmArgs;
+		rmArgs << "-rvf" << snapEmptyDir;
+		rmProcess -> start ("rm",rmArgs);
+		rmProcess -> waitForFinished();
+		emptydir.mkpath(snapEmptyDir);
+	}
+	
 	currentUser = myHome;
 	if (currentUser == "/root")
 	{
@@ -110,6 +125,7 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	connect ( ui.actionImport, SIGNAL( triggered() ), this, SLOT( importProfile() ) );	//action import profile
 	connect ( ui.actionExport, SIGNAL( triggered() ), this, SLOT( exportProfile() ) );	//action export profile
 	connect ( ui.actionDuplicate_Profile, SIGNAL( triggered() ), this, SLOT( duplicateProfile() ) ); //action duplicate profile
+	connect( ui.actionDescription, SIGNAL(triggered()), this, SLOT(changeProfileDescription()));	//menu action changeProfileDescription
 	
 	connect ( ui.action_TaskAdd, SIGNAL( triggered() ), this, SLOT( add() ) ); 			//action add task
 	connect ( ui.action_TaskModify, SIGNAL( triggered() ), this, SLOT( modify() ) ); 		//action modify task
@@ -176,7 +192,8 @@ void luckyBackupWindow::exitApp()
 {
 	if (NOWexecuting)		//if a profile execution is in progress just minimize to tray
 	{
-		minimizeTray();
+		if (QSystemTrayIcon::isSystemTrayAvailable ())
+			minimizeTray();
 		return;
 	}
 	if (isProfileSaved() == 0)	//if the current profile is not saved, ask the user if he/she wants to
@@ -386,14 +403,15 @@ void luckyBackupWindow::renameCurrentProfile()
 	}
 	if (currentProfile == defaultProfile)
 	{
-		InfoData.append(tr("default","full phrase: 'default profile <PROFILENAME> renamed successfully to <NEWPROFILENAME>'") +" ");
+		InfoData.append(tr("default profile","full phrase: 'default profile <PROFILENAME> renamed successfully to <NEWPROFILENAME>'."));
 		defaultProfile = newProfile;
 		saveSettings();
 	}
-	InfoData.append(tr("profile",
-		"full phrase: 'profile <PROFILENAME> renamed successfully to <NEWPROFILENAME>'") + " <b>" + profileName + "</b><br>...<font color=green>"
-		+ tr("renamed successfully to",
-		"full phrase: 'profile <PROFILENAME> renamed successfully to <NEWPROFILENAME>'") + "</font> <b>" + newProfileName +"</b>");
+	else
+		InfoData.append(tr("profile", "full phrase: 'profile <PROFILENAME> renamed successfully to <NEWPROFILENAME>'"));
+	
+	InfoData.append(" <b>" + profileName + "</b><br>...<font color=green>"	+ tr("renamed successfully to",
+		"full phrase: '(default) profile <PROFILENAME> renamed successfully to <NEWPROFILENAME>'") + "</font> <b>" + newProfileName +"</b>");
 	setCurrentProfile(newProfile);
 	createProfileCombo();	// update the profile combobox with all existing profiles and set index to currentProfile
 	loadCurrentProfile();	// load the current profile
@@ -503,6 +521,7 @@ void luckyBackupWindow::exportProfile()
 	setCurrentProfile(currentProfile);		//reset all currentProfile variables
 }
 
+
 // duplicateProfile ================================================================================================================================
 // duplicates the current profile
 void luckyBackupWindow::duplicateProfile()
@@ -578,6 +597,31 @@ void luckyBackupWindow::duplicateProfile()
 	loadData=""; saveData=""; createData="";
 }
 
+// changeProfileDescription ================================================================================================================================
+// Changes the profile description
+void luckyBackupWindow::changeProfileDescription()
+{
+	InfoData="";
+	
+	textDialog textdialog ("ProfileDescription", profileDescription, this);
+	textdialog.exec();
+	
+	if (textdialog.getGoOn() == 0)
+		return;
+
+	profileDescription = textdialog.getUserInput();
+	
+	QString profileDescriptionDisplay = profileDescription;
+	profileDescriptionDisplay.replace("\n","<br>");
+	
+
+	InfoData.append(tr("The description of profile","full phrase: 'The description of profile <PROFILENAME> set to: <DESCRIPTION>'") + " <b>" + profileName + "</b> " + tr("set to","full phrase: 'The description of profile <PROFILENAME> set to: <DESCRIPTION>'") + 
+	":<br>" + profileDescriptionDisplay);
+	
+	ui.textBrowser_info -> setText(InfoData);	//update the info window
+	savedProfile = FALSE;			//change profile status to "unsaved"
+}
+
 // duplicateTask ================================================================================================================================
 // duplicates the current task (creates a new task - same as selected - and opens modify dialog)
 void luckyBackupWindow::duplicateTask()
