@@ -22,7 +22,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 08 Jun 2010
+ last modified 		: 01 Sep 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -30,6 +30,8 @@
 #include "logDialog.cpp"
 #include "manageWizard.cpp"
 
+#include "calcDiffThread.cpp"
+
 // class manageDialog Constructor=================================================================================================
 // Displays the manage backups of a task dialog
 manageDialog::manageDialog (QDialog *parent) : QDialog (parent)
@@ -60,6 +62,12 @@ manageDialog::manageDialog (QDialog *parent) : QDialog (parent)
 	}
 
 	uiG.setupUi(this);
+	
+	calcdiffthread = new CalcDiffThread(this);
+	abortCalcThread = FALSE;
+	connect( calcdiffthread, SIGNAL(updateViewer(const QString, const bool)), this, SLOT(refreshDifWindow(const QString &, const bool &)) );
+	connect( calcdiffthread, SIGNAL(terminated()), this, SLOT(calcDiffEnd()));
+	connect( calcdiffthread, SIGNAL(finished()), this, SLOT(calcDiffEnd()));
 
 	//connect pushButton SLOTs ----------------
 	connect ( uiG.pushButton_cancel, SIGNAL( clicked() ), this, SLOT( cancel() ) );
@@ -91,6 +99,8 @@ manageDialog::manageDialog (QDialog *parent) : QDialog (parent)
 	uiG.lineEdit_destination -> setText(dest);
 	uiG.lineEdit_source	-> setText(source);
 	
+	(uiG.textBrowser_snapshot->document())->setMaximumBlockCount(50000);	// set maximum blocks to avoid freeze
+	
 	updateSnapshots();	// update the snapshots listWidget
 	SnapshotsListSelected(); //set currentSnapshotString & No. Will also call fixGui()
 }
@@ -101,6 +111,14 @@ void manageDialog::cancel()
 	close();
 }
 
+//do the same if the main window close button (or alt+F4) is pressed
+ void manageDialog::closeEvent(QCloseEvent *event)
+ {
+	// do not close the window if a calc thread is still running
+	if (calcdiffthread->isRunning())
+		event->ignore();
+ }
+
 // SLOT logView =====================================================================================================================
 // Display the logfile
 void manageDialog::logView()
@@ -155,9 +173,9 @@ void manageDialog::fixGui()
 	sourceVisible = TRUE;
 
 	//Thesw will become false if relevant pushButtons have to be disabled
-	bool viewLogVisible = TRUE;
-	bool deleteVisible = TRUE;
-	bool restoreVisible = TRUE;
+	viewLogVisible = TRUE;
+	deleteVisible = TRUE;
+	restoreVisible = TRUE;
 	
 	syncTYPE = FALSE;	// This will become true if it is a sync task
 	
@@ -344,38 +362,84 @@ void manageDialog::SnapshotsListSelected()
 // calculate differences between source and snapshot
 // Calls readDirEntries()
 void manageDialog::calculateDifferences()
-{	
-	if (!snapCalculated.at(CurrentSnapshotNo))	// if the differences have not been calculated yet
+{
+	// if the thread is running (meaning: STOP is pressed)
+	if (calcdiffthread -> isRunning())
 	{
-		// first ask the user if he/she wants to go on
-		QString boxMessage = tr("WARNING: The application might seem frozen for a long time if the amount of data to take into consideration is huge.") + 
-					"\n" + tr("Are you sure you wish to continue ??");
-		textDialog textdialogQ ("QtQuestion", boxMessage, this);
-		textdialogQ.exec();
-
-		if (textdialogQ.getGoOn() == 0)		//if user answers yes
-			return;
-		
-		// Update the textBrowser_snapshot with differences data
-		calculatedDifferences.replace(CurrentSnapshotNo, readDirEntries(dest) );
-		snapCalculated.replace(CurrentSnapshotNo, TRUE );
+		uiG.textBrowser_snapshot -> setText (tr("Please wait until the thread is terminated"));
+		uiG.pushButton_calculate_diffs -> setEnabled(FALSE);
+		calcdiffthread -> setAbort(TRUE);
+		abortCalcThread = TRUE;
+		return;
 	}
 	
-	// hide stuff and show the calculated diffs
+	// change the gui a bit
 	if (syncTYPE)
 	{
 		uiG.label_source -> setVisible(FALSE);
 		uiG.lineEdit_source -> setVisible(FALSE);
 		uiG.treeView_source -> setVisible (FALSE);
 	}
-	//uiG.pushButton_calculate_diffs -> setEnabled(destVisible);
-	uiG.textBrowser_snapshot -> setVisible (TRUE);
 	uiG.treeView_browser -> setVisible (FALSE);
-	uiG.textBrowser_snapshot -> setText (calculatedDifferences.at(CurrentSnapshotNo));
-}
+	uiG.textBrowser_snapshot -> setVisible (TRUE);
+	
+	if (!snapCalculated.at(CurrentSnapshotNo))	// if the differences have not been calculated yet
+	{
+		//disable some gui stuff during calculations
+		uiG.pushButton_delete -> setEnabled(FALSE);
+		uiG.pushButton_restore -> setEnabled(FALSE);
+		uiG.pushButton_viewLog -> setEnabled(FALSE);
+		uiG.pushButton_cancel -> setEnabled(FALSE);
+		uiG.pushButton_calculate_diffs -> setText(tr("STOP"));
+		uiG.pushButton_calculate_diffs -> setToolTip(tr("Stop calculations NOW"));
 		
+		
+		calcdiffthread -> passParams(dest, dest, CurrentSnapshotDirectory, CurrentSnapshotString, sourceLast, source, CurrentSnapshotNo, currentSnaps, syncTYPE);
+		calcdiffthread -> start();
+	}
+	else
+		uiG.textBrowser_snapshot -> setText (calculatedDifferences.at(CurrentSnapshotNo));
+}
+
+// calcDiffEnd  =====================================================================================================================
+// // diffs have been calculated - update viewer with new text
+void manageDialog::calcDiffEnd()
+{
+	// Update the textBrowser_snapshot with differences data
+	calculatedDifferences.replace(CurrentSnapshotNo, calcdiffthread -> returnResult() );
+	uiG.textBrowser_snapshot -> setText (calculatedDifferences.at(CurrentSnapshotNo));
+
+	if (abortCalcThread)
+		uiG.textBrowser_snapshot -> append ("<p align=\"center\"><font color=red><b>" + tr("Calculations terminated by user") + "</b></font></p>");
+	else
+		snapCalculated.replace(CurrentSnapshotNo, TRUE );
+	
+	abortCalcThread = FALSE;
+	calcdiffthread -> setAbort(FALSE);
+	
+	// re-enable gui stuff
+	uiG.pushButton_delete -> setEnabled(deleteVisible);
+	uiG.pushButton_restore -> setEnabled(restoreVisible);
+	uiG.pushButton_viewLog -> setEnabled(viewLogVisible);
+	uiG.pushButton_cancel -> setEnabled(TRUE);
+	uiG.pushButton_calculate_diffs -> setEnabled(TRUE);
+	uiG.pushButton_calculate_diffs -> setText(tr("Calculate differences"));
+	uiG.pushButton_calculate_diffs -> setToolTip(tr("Calculate the differences between the source and the selected snapshot"));
+}
+
 // FUNCTIONS-------------------------------------------------------------------------------------
 
+// refreshDifWindow =====================================================================================================
+//Refresh the calc diff window with text
+void manageDialog::refreshDifWindow(const QString &newText, const bool &appendText)
+{
+	if (appendText)
+		uiG.textBrowser_snapshot -> append(newText);
+	else
+		uiG.textBrowser_snapshot -> setText(newText);
+//	QCoreApplication::processEvents();
+}
+
 // updateSnapshots  =====================================================================================================================
 // update the snapshots date & times listwidget
 void manageDialog::updateSnapshots()
@@ -416,308 +480,16 @@ void manageDialog::updateSnapshots()
 	}
 	
 	if (emptySnapList)
+	{
 		uiG.listWidget_dates -> addItem (tr("not available","refers to a date-time"));
+		calculatedDifferences.append("");
+		snapCalculated.append(FALSE);
+	}
 
 	// select the latest snapshot
 	uiG.listWidget_dates	-> setCurrentRow(uiG.listWidget_dates -> count() - 1);
 }
 
-// readDirEntries =====================================================================================================================
-// Read all entries of a directory except stuff we do not want to
-QString manageDialog::readDirEntries(QString dirToReadString)
-{
-	QFileInfoList readRecursive(QString);
-	QString returnString = "";
-	//uiG.textBrowser_snapshot -> append ("<br><br>" + tr("Reading destination... "));
-	QFileInfoList returnDirContents = readRecursive(dirToReadString);		//this is the destination as a Qfileinfo list
-	
-	int countDirEntries=0, countReturnEntries=0;
-
-	// Remove the "luckybackup snapshots root" directory from the returnDirContents list
-	countReturnEntries = 0;
-	while ( (countReturnEntries < returnDirContents.size())  && (!syncTYPE) )
-	{
-		QFileInfo localFileInfo = returnDirContents.at(countReturnEntries);
-		if ( (localFileInfo.filePath()+"/").contains((dest + snapDefaultDir)) )
-			returnDirContents.removeAt(countReturnEntries);
-		else
-			countReturnEntries++;
-	}
-
-	
-	// Remove files/dirs listed at changes.file from the QFileInfo list (destination)
-	QStringList removedFiles;
-	removedFiles.clear();
-	count = CurrentSnapshotNo+1;
-	while ( (count < currentSnaps)  && (!syncTYPE) )
-	{
-		snapchangesfilename = snapChangesDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
-					(Operation[currentOperation] -> GetSnapshotsListItem(count)) + ".changes.log";
-		snapfile.setFileName(snapchangesfilename);
-		snapfile.open(QIODevice::ReadOnly | QIODevice::Text);
-		QTextStream in(&snapfile);
-		while (!in.atEnd())
-			removedFiles.append(in.readLine());
-			
-		snapfile.close();
-		
-		count++;
-	}
-	countReturnEntries = 0;
-	
-	while ( (countReturnEntries < returnDirContents.size())  && (!syncTYPE) )
-	{
-		QFileInfo localFileInfo = returnDirContents.at(countReturnEntries);
-		QString destFile = localFileInfo.filePath();
-		destFile.remove(dest, Qt::CaseSensitive);
-		
-		countDirEntries = 0;
-		bool removed = FALSE;
-		while (countDirEntries < removedFiles.size())
-		{
-			if (destFile == removedFiles.at(countDirEntries))
-			{
-				removed = TRUE;
-				returnDirContents.removeAt(countReturnEntries);
-			}
-			countDirEntries++;
-		}
-		if (removed)
-			removed = FALSE;
-		else
-			countReturnEntries++;
-	}
-
-	// Replace destination directory data with snapshot data - NOT in sync mode
-	QDir currentsnapdir(CurrentSnapshotDirectory);
-	if ( (currentsnapdir.exists()) && (!syncTYPE) )
-	{
-		QFileInfoList currentsnapdirContents = readRecursive(CurrentSnapshotDirectory); // this is the snapshots directory as a QFileInfo list
-		countDirEntries = 0;
-		
-		while (countDirEntries < currentsnapdirContents.size())
-		{
-			//strip off beginning of snapshot file path
-			QFileInfo snapFileInfo = currentsnapdirContents.at(countDirEntries);
-			QString snapFile = snapFileInfo.filePath();
-			snapFile.remove(dest + snapDefaultDir + CurrentSnapshotString + "/" + sourceLast, Qt::CaseSensitive);
-			
-			countReturnEntries = 0;
-			bool replaced = FALSE;
-			while (countReturnEntries < returnDirContents.size())
-			{
-				QFileInfo localFileInfo = returnDirContents.at(countReturnEntries);
-				QString destFile = localFileInfo.filePath();
-				destFile.remove(dest, Qt::CaseSensitive);
-				if (snapFile == destFile)
-				{
-					returnDirContents.removeAt(countReturnEntries);
-					returnDirContents.insert(countReturnEntries,snapFileInfo);
-					replaced = TRUE;
-				}
-				countReturnEntries++;
-			}
-			if (!replaced)
-				returnDirContents.append(snapFileInfo);
-			countDirEntries++;
-		}
-	}
-	
-	// Calculate differences between snapshot and source
-	QFileInfoList changedFiles, existingSource, existingSnap;
-	QString changedfiles="", existingsource = "", existingsnap = "";
-	QList<bool> snapMatchesSource;
-
-	QFileInfoList sourceDirAsList = readRecursive(source);	// This is source as a QFileInfo list
-	countDirEntries = 0;
-	while (countDirEntries < sourceDirAsList.size())
-	{
-		bool foundMatchSourceToSnap = FALSE;	// If a file with some filename exists at the source and the snapshot
-		// strip off beginning of source file path
-		QFileInfo sourceFileInfo = sourceDirAsList.at(countDirEntries);
-		QString sourceFile = sourceFileInfo.filePath();
-		if (sourceFile.startsWith(source))
-			sourceFile.remove(source, Qt::CaseSensitive);
-	
-		// compare with every file in snapshot
-		countReturnEntries = 0;
-		while (countReturnEntries < returnDirContents.size())
-		{
-			if (countDirEntries == 0)
-				snapMatchesSource.append(FALSE); // build a <bool> list
-
-			//strip off beginning of snapshot file path
-			QFileInfo snapFileInfo = returnDirContents.at(countReturnEntries);
-			QString snapFile = snapFileInfo.filePath();
-			if (snapFile.startsWith(dest + snapDefaultDir + CurrentSnapshotString) )
-				snapFile.remove(dest + snapDefaultDir + CurrentSnapshotString + "/" + sourceLast, Qt::CaseSensitive);
-			if (snapFile.startsWith(dest))
-				snapFile.remove(dest, Qt::CaseSensitive);
-			
-			// 1. Data that have changed at source.
-			//	The snapshot data will replace the relevant source data, at RESTORE
-			if (snapFile == sourceFile)
-			{
-				snapMatchesSource.replace(countReturnEntries, TRUE);
-				foundMatchSourceToSnap = TRUE;
-				if ((snapFileInfo.lastModified() != sourceFileInfo.lastModified()) ||
-				(snapFileInfo.size() != sourceFileInfo.size()))
-				{
-					changedFiles.append(snapFileInfo);
-					if (snapFileInfo.isDir())
-						snapFile.append("/");
-					if (changedfiles.size() < 10000)
-						changedfiles.append("* <b>" + snapFile + "</b> - " + snapFileInfo.lastModified().toString("yyyy MMM dd - hh:mm:ss") + "<br>");
-					
-					//else
-					//	break;
-				}
-			}
-			
-			countReturnEntries++;
-		}
-		// 2. Data that exist at the source but not at the snapshot
-		//	These will be deleted at RESTORE if "delete existing source data that do not exist at the backup" is checked
-		if (!foundMatchSourceToSnap)
-		{
-			existingSource.append(sourceFileInfo);
-			if (sourceFileInfo.isDir())
-				sourceFile.append("/");
-			if (existingsource.size() < 10000)
-				existingsource.append("* <b>" + sourceFile + "</b> - " + sourceFileInfo.lastModified().toString("yyyy MMM dd - hh:mm:ss") + "<br>");
-		}
-		
-		countDirEntries++;
-	}
-
-	// 3. Data that exist at the snapshot but not at the source.
-	// 	These will be transfered over at RESTORE
-	countReturnEntries = 0;
-	while (countReturnEntries < snapMatchesSource.size())
-	{
-		if (!snapMatchesSource.at(countReturnEntries))
-		{
-			QFileInfo snapFileInfo = returnDirContents.at(countReturnEntries);
-			QString snapFile = snapFileInfo.filePath();
-			if (snapFile.startsWith(dest + snapDefaultDir + CurrentSnapshotString) )
-				snapFile.remove(dest + snapDefaultDir + CurrentSnapshotString + "/" + sourceLast, Qt::CaseSensitive);
-			if (snapFile.startsWith(dest))
-				snapFile.remove(dest, Qt::CaseSensitive);
-			if (snapFileInfo.isDir())
-				snapFile.append("/");
-			
-			existingSnap.append(snapFileInfo);
-			if (existingsnap.size() < 10000)
-				existingsnap.append("* <b>" + snapFile + "</b> - " + snapFileInfo.lastModified().toString("yyyy MMM dd - hh:mm:ss") + "<br>");
-		}
-		countReturnEntries++;
-	}
-
-	returnString.append("<font color=red><p align=\"center\">");
-	if (syncTYPE)
-		returnString.append("		<b>" + tr("Sync dir A & B differences") + "</b><br>");
-	else
-		returnString.append("		<b>" + tr("Snapshot and source differences") + "</b><br>");
-	returnString.append("_______________________________________________________</p>");
-	if (changedfiles != "")
-	{
-		returnString.append("</font><font color=blue><p align=\"center\">");
-		if (syncTYPE)
-			returnString.append(" " + tr("Sync dir B data that also exists at sync dir A and is different") + "</p>");
-		else
-		{
-			returnString.append(" " + tr("Snapshot data that also exists at the source and is different") + "<br>");
-			returnString.append(" " + tr("The snapshot data will replace the source data during RESTORE") + "</p>");
-		}
-		returnString.append(changedfiles);
-		if (changedfiles.size() > 9900)
-			returnString.append(" <br>" + tr("Data amount is huge. Displaying only first entries") + "<br>");
-		returnString.append("_______________________________________________________<br>");
-	}
-	if (existingsnap != "")
-	{
-		returnString.append("</font><font color=green><p align=\"center\">");
-		if (syncTYPE)
-			returnString.append(" " + tr("Sync dir B data that do NOT exist at sync dir A") + "</p>");
-		else
-		{
-			returnString.append(" " + tr("Snapshot data that do NOT exist at the source") + "<br>");
-			returnString.append(" " + tr("These will be transfered over at the source during RESTORE") + "</p>");
-		}
-		returnString.append(existingsnap);
-		if (existingsnap.size() > 9900)
-			returnString.append(" <br>" + tr("Data amount is huge. Displaying only first entries") + "<br>");
-		returnString.append("_______________________________________________________<br>");
-	}
-	if (existingsource != "")
-	{
-		returnString.append("</font><font color=magenta><p align=\"center\">");
-		if (syncTYPE)
-			returnString.append(" " + tr("Sync dir A data that do NOT exist at sync dir B") + "</p>");
-		else
-		{
-			returnString.append(" " + tr("Source data that do NOT exist at the snapshot") + "<br>");
-			returnString.append(" " + tr("These will be deleted during RESTORE only if you enable the option:") + "<br>");
-			returnString.append(" \"<b>" + tr("delete existing source data that do not exist at the backup") + "</b>\"</p>");
-		}
-		returnString.append(existingsource);
-		if (existingsource.size() > 9900)
-			returnString.append(" <br>" + tr("Data amount is huge. Displaying only first entries") + "<br>");
-		returnString.append("_________________________________________________________________<br>");
-	}
-	returnString.append("</font>");
-
-	return returnString ;
-}
-
-// readRecursive ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-// Extract a QFileInfoList from a directory's path
-QFileInfoList readRecursive(QString dirToReadString)
-{
-	QFileInfoList readRecursive(QString);	
-	
-	QDir dirToRead(dirToReadString);
-	dirToRead.setFilter(QDir::AllDirs | QDir::NoDotAndDotDot | QDir::AllEntries | QDir::Hidden);
-	dirToRead.setSorting(QDir::Name | QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
-	
-	QFileInfoList DirContentsStart = dirToRead.entryInfoList();
-	QFileInfoList returnDirContentsFinal;
-
-
-	QStack<QDir> dirStack;
-	dirStack.push(dirToRead);
-	
-	while( !dirStack.empty() )
-	{
-		QDir lastDir = dirStack.last();
-		lastDir.setFilter(QDir::AllDirs | QDir::NoDotAndDotDot | QDir::AllEntries | QDir::Hidden);
-		lastDir.setSorting(QDir::Name | QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
-		QFileInfoList flist = lastDir.entryInfoList( );
-		dirStack.pop();
-
-		foreach (QFileInfo localFileInfo, flist)
-		{
-			returnDirContentsFinal.append(localFileInfo);
-			if (localFileInfo.isDir())
-			{
-				QDir dirent( localFileInfo.absoluteFilePath() );
-				dirStack.push( dirent );
-			}
-		}
-	}
-
-
-	// old way to do stuff. Delete it if the "stack" way proves to be ok
-/*	foreach (QFileInfo localFileInfo, DirContentsStart)
-	{
-		returnDirContentsFinal.append(localFileInfo);
-		if (localFileInfo.isDir())
-			returnDirContentsFinal.append(readRecursive(localFileInfo.filePath()));
-	}
-*/
-	return returnDirContentsFinal;
-}
-
 
 // end of manage.cpp ---------------------------------------------------------------------------
 
