@@ -23,7 +23,7 @@ Display a dialog. Adds a new or modifies an existing operation
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 11 Jun 2010
+ last modified 		: 18 Oct 2010
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -607,6 +607,9 @@ operation *modifyDialog::fillOperationArray()
 
 	// set connection ----------------------------------------------------------------------------
 	pTask -> SetConnectRestore	("");
+	
+	//set task description --------------------------------------------------------------------------------------------------------
+	pTask -> SetDescription ( uiM.textEdit_Description -> toPlainText() );
 
 	// set operation type ------------------------------------------------------------------------------
 	if (uiM.comboBox_Type -> currentIndex()==0)
@@ -630,8 +633,9 @@ operation *modifyDialog::fillOperationArray()
 	}
 	
 	// also set the keep snapshots spinbox to "1" if remote destination is used
-	if ( (uiM.groupBox_remote -> isChecked()) && (uiM.radioButton_remoteDestination -> isChecked()) )
-		uiM.spinBox_snapshotsKeep -> setValue (1);
+	// Commended bacause remote snapshots are now supported - safely delete this
+	//if ( (uiM.groupBox_remote -> isChecked()) && (uiM.radioButton_remoteDestination -> isChecked()) )
+	//	uiM.spinBox_snapshotsKeep -> setValue (1);
 
 	//set source & destination ------------------------------------------------------------------------------------------------
 	pTask -> SetSource		( uiM.lineEdit_source -> text() );
@@ -730,6 +734,8 @@ operation *modifyDialog::fillOperationArray()
 void modifyDialog::fillModifyWindow(operation *pTask)
 {
 	uiM.lineEdit_name 		-> setText	(pTask -> GetName() );
+	
+	uiM.textEdit_Description 	-> setPlainText	(pTask	-> GetDescription() );
 
 	if (pTask -> GetTypeDirContents())
 		uiM.comboBox_Type -> setCurrentIndex(0);
