@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 05 May 2010
+ last modified 		: 17 Aug 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -40,8 +40,9 @@ class operation
 	public:
 		operation()								//constructor
 		{
-			itsName= "";
+			itsName = "";
 			itsArguments << "";
+			itsDescription = "";
 			itsSource = "";
 			itsDestination = "";
 			itsConnectRestore = "";
@@ -61,6 +62,7 @@ class operation
 
 		//Functions - get class operation data--------------------------------------------------------------------------------------
 		QString GetName() const 		{return itsName;}
+		QString GetDescription() const 		{return itsDescription;}
 		QStringList GetArgs() const 		{return itsArguments;}
 		bool GetIncluded () const 		{return itsIncluded;}
 		bool GetCRITICAL () const 		{return itsCRITICAL;}
@@ -139,6 +141,7 @@ class operation
 
 		//Functions - set class operation data --------------------------------------------------------------------------------------
 		void SetName(QString name) 							{itsName = name;}
+		void SetDescription(QString description)					{itsDescription = description;}
 
 		// Task state & general properties
 		void SetIncluded(bool included) 					{itsIncluded = included;}
@@ -250,6 +253,7 @@ class operation
 	private:
 		QString itsName;
 		QStringList itsArguments;
+		QString itsDescription;
 		bool itsIncluded;
 		bool itsCRITICAL;
 		bool itsWARNING;
