@@ -23,7 +23,7 @@ Display a dialog. Schedules profiles via cron
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 12 Jun 2010
+ last modified 		: 30 Aug 2010
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -119,7 +119,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 		if ( (tempAppName != appName) || (tempAppVersion < validScheduleVersion) )//check if the file is a valid luckybackup schedule file
 		{
 			message = tr("The existent schedule file is not a valid luckyBackup v.","v is for version")
-				+ countStr.setNum(appVersion) + " "+tr("file")+"<br><br>"+tr("Starting from scratch")+"...<br>" ;
+				+ countStr.setNum(appVersion) + tr(" file","BEWARE of the whitespace before file")+"<br><br>"+tr("Starting from scratch")+"...<br>" ;
 			textDialog textdialogW ("QtWarning", message, this);
 			textdialogW.exec();
 			scheduleFile.remove();
@@ -458,6 +458,7 @@ void scheduleDialog::okaySchedulePressed()
 		QMessageBox::information(this, appName, tr("Invalid profile")+"<br><br>" + proFile.errorString());
 		return;
 	}
+/*	I have disabled this check as TOO much. If you wish to re-enable it, use the new profile "text format" from loadcurrentprofile()
 	else	//read the file to check if it's valid
 	{
 		QDataStream in(&proFile);
@@ -474,12 +475,12 @@ void scheduleDialog::okaySchedulePressed()
 		if ( (tempAppName != appName) || (tempAppVersion < validProfileVersion) )//check if the file is a valid luckybackup profile
 		{
 			message = tr("The profile you are trying to open is not a valid luckyBackup v.","v is for version")+" "
-				+ countStr.setNum(appVersion) + " "+tr("profile")+"<br><br>";
+				+ countStr.setNum(appVersion) + tr(" profile","BEWARE of the whitespace in the beginning")+"<br><br>";
 			QMessageBox::warning(this, appName, message, QMessageBox::Ok | QMessageBox::Default);
 			return;
 		}
 	}
-	proFile.close();
+*/	proFile.close();
 
 	//read fields & fill array
 	tempOp -> SetProfileName (uiS.comboBox_profile -> currentText());
